Gater
=====

.. automodule:: stonesoup.gater
    :no-members:

.. automodule:: stonesoup.gater.base
    :show-inheritance:

Distance
--------

.. automodule:: stonesoup.gater.distance
   :show-inheritance:

Filtered
--------

.. automodule:: stonesoup.gater.filtered
   :show-inheritance:
